.. Uxarray documentation master file, created by
   sphinx-quickstart on Tues Oct 26 08:45:00 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. meta::
   :description: Uxarray Python module
   :keywords: weather research and forecasting,
              model, weather, numerical weather prediction, model,
              matplotlib, cartopy, ncar, ucar, cisl, UC Davis, SEATs, ugrid,
              national center for atmospheric research,
              university corporation for atmospheric research


.. .. image:: _static/images/nsf.png
..    :scale: 100%
..   :align: right

.. |
.. |

Uxarray
===========

Uxarray aims to provide xarray styled functionality for unstructured grid datasets
following ugrid conventions. More information on ugrid conventions can be found `here <https://ugrid-conventions.github.io/ugrid-conventions/>`_.

.. toctree::
   :maxdepth: 2

   ./installation
   ./contributing
   ./api
   ./examples
   ./citation
   ./support


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


--------------------

Support
=======

.. raw:: html

   <table>
     <tr style="height:80px">
       <td style="width:20%"><a href="https://www.nsf.gov/"><img src="_static/images/logos/NSF_logo.png" alt="NSF Logo" width="65"/></a></td>
       <td>Project Raijin, entitled "Collaborative Research: EarthCube Capabilities: Raijin: Community Geoscience Analysis Tools for Unstructured Mesh Data", was awarded by NSF 21-515 EarthCube (Award Number (FAIN): 2126458) on 08/19/2021. The award period of performance has a start date of 09/01/2021 and end date of 08/31/2024.</td>
     </tr>
     <tr style="height:80px">
       <td><a href="https://www.energy.gov/science/office-science"><img src="_static/images/logos/DOE_Office_of_Science_logo.png" alt="DOE Logo" width="250"/></a></td>
       <td>SEATS is funded by the Regional and Global Modeling and Analysis (RGMA) program area in the U.S. Department of Energy (DOE) Earth and Environmental System Modeling Program which is part of the Earth and Environmental Systems Sciences Division of the Office of Biological and Environmental Research in DOE’s Office of Science.</td>
     </tr>
     <tr style="height:80px">
       <td><a href="https://www.earthcube.org/"><img src="_static/images/logos/EarthCube_logo.png" alt="EarthCube Logo" width="50"/></a></td>
       <td><a href="https://www.earthcube.org/">EarthCube</a> aims to transform the conduct of geosciences research by developing and maintaining a well-connected and facile environment that improves access, sharing, visualization, and analysis of data and related resources.</td>
     </tr>
     <tr style="height:80px">
       <td><a href="https://pangeo.io/"><img src="_static/images/logos/PANGEO_logo.png" alt="PANGEO Logo" width="160"/></a></td>
       <td><a href="https://pangeo.io/">Pangeo</a> supports collaborative efforts to develop software and infrastructure to enable Big Data geoscience research.</td>
     </tr>
   </table>
